// $Id: server.cpp 77915 2007-04-04 19:15:03Z elliott_c $

#include "tao/ORB.h"
#include "ace/Get_Opt.h"
#include "ace/Service_Config.h"

ACE_RCSID (Bug_2735_Regression,
           server,
           "$Id: server.cpp 77915 2007-04-04 19:15:03Z elliott_c $")

static const ACE_TCHAR* server_strat =
  ACE_STATIC_SERVICE_DIRECTIVE ("Server_Strategy_Factory",
                                "-ORBConcurrency thread-per-connection");
static const ACE_TCHAR* foo_strat =
  ACE_STATIC_SERVICE_DIRECTIVE ("Foo_Strategy_Factory", "");

enum Factory_Strategy { SERVER_STRATEGY, FOO_STRATEGY };

static Factory_Strategy factory_strategy = SERVER_STRATEGY;

static int
parse_args (int argc, ACE_TCHAR *argv[])
{
  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT ("fs"));
  int c;

  while ((c = get_opts ()) != -1)
    switch (c)
      {       
      case 'f':
        factory_strategy = FOO_STRATEGY;
        break;
      case 's':
        factory_strategy = SERVER_STRATEGY;
        break;
      case '?':
      default:
        ACE_ERROR_RETURN ((LM_ERROR,
                           "usage: %s "
                           "-f "
                           "-s "
                           "\n", 
                           argv [0]),
                          -1);
      }
  return 0;   
}  


int
ACE_TMAIN (int argc, ACE_TCHAR *argv[])
{
  try
    {
      if (parse_args (argc, argv) == -1)
        return -1;

      int targc = 3;
      const char* targv[] = { "server", "-ORBSvcConfDirective", 0 };
      switch (factory_strategy)
        {
        case FOO_STRATEGY:
          targv[2] = ACE_TEXT_ALWAYS_CHAR (foo_strat);
          break;
        case SERVER_STRATEGY:
          targv[2] = ACE_TEXT_ALWAYS_CHAR (server_strat);
          break;
        }
      CORBA::ORB_var orb = CORBA::ORB_init (targc, const_cast<char**> (targv));
      orb->destroy ();
    }
  catch (const CORBA::Exception& ex)
    {
      ex._tao_print_exception ("Exception caught:");
      return 1;
    }

  return 0;
}
